@@ -23,7 +23,7 @@ class R3sponse(object):
 
 	# response functions.
 	def default_response(self):
-		return ResponseObject()
+		return self.ResponseObject()
 	def success_response(self,
 		# the message (must be param #1).
 		message, 
@@ -108,7 +108,7 @@ class R3sponse(object):
 	def get_request_parameters(self, request, identifiers=[], optional=False, empty_value=None):
 		if isinstance(identifiers, str):
 			return self.error_response("__get_request_params__ is used to retrieve several identifiers (array format not string).")
-		params = ResponseObject()
+		params = self.ResponseObject()
 		for param in identifiers:
 			param_value, response = self.get_request_parameter(request, param)
 			param = param.split(":")[0]
@@ -158,6 +158,8 @@ class R3sponse(object):
 		# option 3:
 		# the response dict (leave message None to use).
 		response={},
+		# print the response as json.
+		json=False,
 		# optionals:
 		# the log level for printing to console.
 		log_level=0,
@@ -188,7 +190,10 @@ class R3sponse(object):
 				raise TypeError(e)
 		if comparison:
 			#print(f"{Formats.Date().seconds_timestamp} - {color.fill(msg)}")
-			print(f"{color.fill(msg)}")
+			if json and response != {}:
+				print(response)
+			else:
+				print(f"{color.fill(msg)}")
 		if save: 
 			self.__log_to_file__(msg)
 		elif save_errors and _error_:
@@ -239,67 +244,69 @@ class R3sponse(object):
 
 		#
 
-# a response object.
-class ResponseObject(object):
-	def __init__(self):
-		self.success = False
-		self.message = None
-		self.error = None
-	# iterate over self keys & variables.
-	def items(self):
-		return vars(self).items()
-	def keys(self):
-		return list(vars(self).keys())
-	def values(self):
-		return list(vars(self).values())
-	def dict(self, serializable=False):
-		dictionary = {}
-		for key, value in self.items():
-			if serializable:
-				if isinstance(value, object):
-					value = str(value)
-				elif value == "True": value = True
-				elif value == "False": value = False
-				elif value == "None": value = None
-			dictionary[key] = value
-		return dictionary
-	# assign self variables by dictionary.
-	def assign(self, dictionary):
-		if not isinstance(dictionary, dict):
-			raise TypeError("You can only self assign with a dictionary as parameter.")
-		for key,value in dictionary.items():
-			self[key] = value
-	# clean default values.
-	def clean(self):
-		for i in ["error", "message", "success"]:
-			del self[i]
-			#except: a=1
-		return self
-	# count items.
-	def __len__(self):
-		return len(self.keys())
-	# support item assignment.
-	def __setitem__(self, key, value):
-		setattr(self, key, value)
-	def __getitem__(self, key):
-		return getattr(self, key)
-	def __delitem__(self, key):
-		delattr(self, key)
-	# string format.
-	def __str__(self):
-		return self.dict(serializable=True)
-		return json.dumps(self.dict(serializable=True), indent=4)
-		if isinstance(self, dict):
-			return json.dumps(self, indent=4)
-		else:
-			return json.dumps(self.dict(), indent=4)
-	def json(self,):
-		return self.dict(serializable=True)
-		return json.dumps(self.dict(serializable=True), indent=4)
-		return json.dumps(self)
-		return json.dumps(self, default=lambda o: o.__dict__)
-	#def __dict__(self):
-	#	return json.dumps(self.dict(), indent=4)
+
+	# a response object.
+	class ResponseObject(object):
+		def __init__(self):
+			self.success = False
+			self.message = None
+			self.error = None
+		# iterate over self keys & variables.
+		def items(self):
+			return vars(self).items()
+		def keys(self):
+			return list(vars(self).keys())
+		def values(self):
+			return list(vars(self).values())
+		def dict(self, serializable=False):
+			dictionary = {}
+			for key, value in self.items():
+				if serializable:
+					if isinstance(value, object):
+						value = str(value)
+					elif value == "True": value = True
+					elif value == "False": value = False
+					elif value == "None": value = None
+				dictionary[key] = value
+			return dictionary
+		# assign self variables by dictionary.
+		def assign(self, dictionary):
+			if not isinstance(dictionary, dict):
+				raise TypeError("You can only self assign with a dictionary as parameter.")
+			for key,value in dictionary.items():
+				self[key] = value
+		# clean default values.
+		def clean(self):
+			for i in ["error", "message", "success"]:
+				del self[i]
+				#except: a=1
+			return self
+		# count items.
+		def __len__(self):
+			return len(self.keys())
+		# support item assignment.
+		def __setitem__(self, key, value):
+			setattr(self, key, value)
+		def __getitem__(self, key):
+			return getattr(self, key)
+		def __delitem__(self, key):
+			delattr(self, key)
+		# string format.
+		def __str__(self):
+			return json.dumps(self.dict(serializable=True), indent=4) # necessary for str(self)
+			return self.dict(serializable=True) # seems to work for django.
+			if isinstance(self, dict):
+				return json.dumps(self, indent=4)
+			else:
+				return json.dumps(self.dict(), indent=4)
+		def json(self,):
+			return self.dict(serializable=True) # seems to work for django.
+			return self.dict(serializable=True)
+			return json.dumps(self.dict(serializable=True), indent=4)
+			return json.dumps(self)
+			return json.dumps(self, default=lambda o: o.__dict__)
+		#def __dict__(self):
+		#	return json.dumps(self.dict(), indent=4)
 
 # initialized objects.
 r3sponse = R3sponse()
